package com.jiuqi.db.impl;

import com.jiuqi.db.DBFunction;
import java.util.List;
import java.sql.DatabaseMetaData;
import java.sql.SQLException;
import com.jiuqi.db.DBMetaData;

public class SybaseDBMetaData implements DBMetaData
{
    private static final String LeftParenthesis = "(";
    private static final String RightParenthesis = ")";
    private static final String comma = ",";
    private static final String IsNull = " ";
    private static final String NotNull = "not null";
    private static final String space = " ";
    private static final String DEF = " default ";
    private static final String BIT = "bit";
    private static final String TINYINT = "tinyint";
    private static final String SMALLINT = "smallint";
    private static final String INTEGER = "int";
    private static final String BIGINT = "numeric";
    private static final String FLOAT = "float";
    private static final String REAL = "real";
    private static final String DOUBLE = "double precision";
    private static final String NUMERIC = "numeric";
    private static final String DECIMAL = "decimal";
    private static final String CHAR = "char";
    private static final String VARCHAR = "varchar";
    private static final String LONGVARCHAR = "text";
    private static final String TIMESTAMP = "datetime";
    private static final String VARBINARY = "image";
    private static final String LONGVARBINARY = "image";
    private static final String BLOB = "image";
    private static final String CLOB = "image";
    private int maxColumnCount;
    private int maxRecordSize;
    
    private void raise(final String msg) throws SQLException {
        throw new SQLException(msg);
    }
    
    public SybaseDBMetaData(final DatabaseMetaData metaData) throws SQLException {
        this.maxColumnCount = metaData.getMaxColumnsInTable();
        this.maxRecordSize = 1962;
    }
    
    public int databaseType() {
        return 4;
    }
    
    public int maxColumnCount() {
        return this.maxColumnCount;
    }
    
    public int maxRecordSize() {
        return this.maxRecordSize;
    }
    
    public int maxIndexNameLength() {
        return 30;
    }
    
    public int maxFieldNameLength() {
        return 30;
    }
    
    public int maxTableNameLength() {
        return 30;
    }
    
    public int maxColumnByteSize(final int sqlType) throws SQLException {
        int result = 0;
        switch (sqlType) {
            case -7: {
                result = 1;
                break;
            }
            case -6: {
                result = 3;
                break;
            }
            case 5: {
                result = 5;
                break;
            }
            case 4: {
                result = 10;
                break;
            }
            case -5: {
                result = 8;
                break;
            }
            case 6: {
                result = 8;
                break;
            }
            case 7: {
                result = 7;
                break;
            }
            case 2: {
                result = 38;
                break;
            }
            case 3: {
                result = 38;
                break;
            }
            case 1: {
                result = 2048;
                break;
            }
            case 12: {
                result = 2048;
                break;
            }
            case -1: {
                result = 16;
                break;
            }
            case 93: {
                result = 23;
                break;
            }
            case -2: {
                result = 16;
                break;
            }
            case -3: {
                result = 16;
                break;
            }
            case -4: {
                result = 16;
                break;
            }
            case 2004: {
                result = 16;
                break;
            }
            case 2005: {
                result = 16;
                break;
            }
        }
        if (result == 0) {
            this.raise("不支持的数据类型 " + Integer.toString(sqlType));
        }
        return result;
    }
    
    public String getFieldDDL(final int sqlType, final int size, final int scale, final boolean isNull, final String defValue) throws SQLException {
        final StringBuffer result = new StringBuffer();
        switch (sqlType) {
            case -7: {
                result.append("bit");
                result.append(" default 0 ");
                result.append("not null");
                return result.toString();
            }
            case -6: {
                result.append("tinyint");
                break;
            }
            case 5: {
                result.append("smallint");
                break;
            }
            case 4: {
                result.append("int");
                break;
            }
            case -5: {
                result.append("numeric");
                break;
            }
            case 6: {
                result.append("float");
                break;
            }
            case 7: {
                result.append("real");
                break;
            }
            case 8: {
                result.append("double precision");
                break;
            }
            case 2: {
                if (size < 0 || size > 38 || scale < 0 || scale > 38) {
                    this.raise("精度或小数位定义错误");
                }
                result.append("numeric");
                result.append("(");
                result.append(size);
                result.append(",");
                result.append(scale);
                result.append(")");
                break;
            }
            case 3: {
                if (size < 0 || size > 38 || scale < 0 || scale > 38) {
                    this.raise("精度或小数位定义错误");
                }
                result.append("decimal");
                result.append("(");
                result.append(size);
                result.append(",");
                result.append(scale);
                result.append(")");
                break;
            }
            case 1: {
                if (size > 2048 || size <= 0) {
                    this.raise("长度定义错误应在1~2048之间");
                }
                result.append("char");
                result.append("(");
                result.append(size);
                result.append(")");
                break;
            }
            case 12: {
                if (size > 2048 || size <= 0) {
                    this.raise("长度定义错误应在1~2048之间");
                }
                result.append("varchar");
                result.append("(");
                result.append(size);
                result.append(")");
                break;
            }
            case -1: {
                result.append("text");
                break;
            }
            case 91:
            case 92:
            case 93: {
                result.append("datetime");
                break;
            }
            case -3:
            case -2: {
                result.append("image");
                break;
            }
            case -4: {
                result.append("image");
                break;
            }
            case 2004: {
                result.append("image");
                break;
            }
            case 2005: {
                result.append("image");
                break;
            }
        }
        if (result.length() == 0) {
            this.raise("不支持的数据类型");
        }
        result.append(" ");
        if (defValue != null && !defValue.equals("")) {
            result.append(" default ");
            result.append(defValue);
        }
        result.append(" ");
        result.append(isNull ? " " : "not null");
        return result.toString();
    }
    
    public String getDropFieldPreSql(final String tableName, final String fieldName) {
        return "commit";
    }
    
    public String getDropFieldDDL(final String tableName, final String fieldName) {
        return "alter table " + tableName + " drop  " + fieldName;
    }
    
    public boolean getModifyFieldSqls(final String tableName, final String sFieldName, final int sSqlType, final int sSize, final int sScale, final boolean sIsNull, final String sDefValue, final String dFieldName, final int dSqlType, final int dSize, final int dScale, final boolean dIsNull, final String dDefValue, final List sqls) throws SQLException {
        return false;
    }
    
    public boolean getDDLCausesTransactionCommit() {
        return false;
    }
    
    public boolean getDDLIgnoredInTransactions() {
        return false;
    }
    
    public String getDefaultScheme() {
        return null;
    }
    
    public boolean getSupportDropColumn() {
        return true;
    }
    
    public DBFunction createDBFunction() {
        return new SybaseDBFunction();
    }
    
    public boolean getTruncateNumber() {
        return false;
    }
}
